@@ -4,14 +4,12 @@ from .constants import INSTANCES
 from .handlers import CfgParser
 
 
-def get_config(**kwargs):
-    name: str = f"{kwargs.pop('instance', 'default')}.{CfgParser.__name__}"
-
+def get_config(instance: str = "default", **kwargs):
+    name: str = f"{instance}.{CfgParser.__name__}"
     if name not in INSTANCES:
-
+        # a strong reference is required
         instance: CfgParser = CfgParser(name, **kwargs)
         INSTANCES[name] = instance
-
     return INSTANCES[name]
 
 
